@@ -1,7 +1,7 @@
 /*
-  $Id: tokenize.h 14285 2012-02-21 10:18:28Z mvgompel $
+  $Id: tokenize.h 15910 2013-04-03 13:57:51Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/ucto/trunk/include/ucto/tokenize.h $
-  Copyright (c) 2006 - 2012
+  Copyright (c) 2006 - 2013
   Tilburg University
 
   This file is part of Ucto.
@@ -23,8 +23,8 @@
       http://ilk.uvt.nl/frog
 */
 
-#ifndef TOKENIZE_H
-#define TOKENIZE_H
+#ifndef UCTO_TOKENIZE_H
+#define UCTO_TOKENIZE_H
 
 #include <vector>
 #include <map>
@@ -32,7 +32,7 @@
 #include <stdexcept>
 #include "config.h"
 #include "ucto/unicode.h"
-#include "libfolia/document.h"
+#include "ticcutils/LogStream.h"
 
 namespace Tokenizer {
 
@@ -138,82 +138,65 @@ namespace Tokenizer {
     TokenizerClass();
     ~TokenizerClass();
     bool init( const std::string& );
-    void setErrorLog( std::ostream *os ) { theErrLog = os; };
+    void setErrorLog( TiCC::LogStream *os );
 
-    //Tokenize from input stream to FoLiA document
+    // Tokenize from input stream to FoLiA document
     folia::Document tokenize( std::istream& );
     
-    //tokenize folia document
+    // Tokenize a folia document
     bool tokenize(folia::Document& );
-    //..or one element thereof:
-    bool tokenize(folia::FoliaElement *);
-    bool tokenize(folia::FoliaElement *, bool, bool); //more specific variant, will be called by the one above
     
     //Tokenize from input stream to output stream
+    std::vector<Token> tokenizeStream( std::istream& );
     void tokenize( std::istream&, std::ostream& );
     void tokenize( std::istream* in, std::ostream* out){
       // for backward compatability
       return tokenize( *in, *out );};
     
-    //Tokenize a line (a line is NOT a sentence, but an arbitrary line of input)
-    int tokenizeLine( const UnicodeString& );
-    int tokenizeLine( const std::string& );
+    // Tokenize a line (a line is NOT a sentence, but an arbitrary string 
+    //                  of characters, inclusive EOS markers, Newlines etc.)
+    int tokenizeLine( const UnicodeString& ); // Unicode chars
+    int tokenizeLine( const std::string& );   // UTF8 chars
     
     void passthruLine( const std::string&, bool& );    
     
-    bool empty() const { return tokens.empty(); };
-        
     //Processes tokens and initialises the sentence buffer. Returns the amount of sentences found
     int countSentences(bool forceentirebuffer = false); //count the number of sentences (only after detectSentenceBounds) (does some extra validation as well)
     int flushSentences(const int); //Flush n sentences from buffer (does some extra validation as well)
     
-    
-    
-    //Get the begin and end index of the sentence with the specified index
-    bool getSentence( int, int& begin, int& end );
-    
-    //Get the sentence with the specified index as a vector of tokens
-    std::vector<Token*> getSentence( int );    
-    
     //Get the sentence with the specified index as a string (UTF-8 encoded)
-    std::string getSentenceString( unsigned int, const bool = false);
+    std::string getSentenceString( unsigned int );
     
     //Get all sentences as a vector of strings (UTF-8 encoded)
-    std::vector<std::string> getSentences() const;
-            
-    void detectSentenceBounds( const int offset = 0 );
-    void detectQuoteBounds( const int, const UChar);
-    
-    //Does the token buffer terminate with a proper EOS marker?
-    bool terminatesWithEOS( ) const;
-    
+    std::vector<std::string> getSentences();
+
     //Enable verbose mode
     bool setVerbose( bool b=true ) { bool t = verbose; verbose = b; return t; };
-    bool getVerbose() { return verbose; }
+    bool getVerbose() const { return verbose; }
     
     //set debug value
     int setDebug( int d ) { bool dd = tokDebug; tokDebug = d; return dd; };
-    int getDebug() { return tokDebug; }
+    int getDebug() const { return tokDebug; }
     
     //Enable conversion of all output to lowercase
     bool setLowercase( bool b=true ) { bool t = lowercase; lowercase = b; if (b) uppercase = false; return t; };
-    bool getLowercase() { return lowercase; }
+    bool getLowercase() const { return lowercase; }
 
     //Enable passtru mode
     bool setPassThru( bool b=true ) { bool t = passthru; passthru = b; return t; };
-    bool getPassThru() { return passthru; }
+    bool getPassThru() const { return passthru; }
     
     //Enable conversion of all output to uppercase
     bool setUppercase( bool b=true ) { bool t = uppercase; uppercase = b; if (b) lowercase = false; return t; };
-    bool getUppercase() { return uppercase; }
+    bool getUppercase() const { return uppercase; }
 
     //Enable sentence-bound detection
     bool setSentenceDetection( bool b=true ) { bool t = detectBounds; detectBounds = b; return t; }
-    bool getSentenceDetection() { return detectBounds; }
+    bool getSentenceDetection() const { return detectBounds; }
     
     //Enable paragraph detection
     bool setParagraphDetection( bool b=true ) { bool t = detectPar; detectPar = b; return t; }
-    bool getParagraphDetection() { return detectPar; }
+    bool getParagraphDetection() const { return detectPar; }
     
     //Enable quote detection
     bool setQuoteDetection( bool b=true ) { bool t = detectQuotes; detectQuotes = b; return t; }
@@ -234,46 +217,57 @@ namespace Tokenizer {
     std::string getInputEncoding() const { return inputEncoding; };
     
     // set eos marker
-    std::string setEosMarker( const std::string& s = "<utt>") { std::string t = eosmark; eosmark = s; return t; };
-    std::string getEosMarker( ) { return eosmark; }
+    UnicodeString setEosMarker( const std::string& s = "<utt>") { UnicodeString t = eosmark; eosmark =  folia::UTF8ToUnicode(s); return t; };
+    UnicodeString getEosMarker( ) const { return eosmark; }
 
     bool setSentencePerLineOutput( bool b=true ) { bool t = sentenceperlineoutput; sentenceperlineoutput = b; return t; };
-    bool getSentencePerLineOutput() { return sentenceperlineoutput; }
+    bool getSentencePerLineOutput() const { return sentenceperlineoutput; }
     
     bool setSentencePerLineInput( bool b=true ) { bool t = sentenceperlineinput; sentenceperlineinput = b; return t; };
-    bool getSentencePerLineInput() { return sentenceperlineinput; }    
+    bool getSentencePerLineInput() const { return sentenceperlineinput; }    
     
-    std::string getDocID() { return docid; }
-    bool getXMLOutput() { return xmlout; }
-    bool getXMLInput() { return xmlin; }
+    std::string getDocID() const { return docid; }
+    bool getXMLOutput() const { return xmlout; }
+    bool getXMLInput() const { return xmlin; }
+
+    const std::string getTextClass( ) const { return textclass; }
+    const std::string setTextClass( const std::string& cls) {  
+      std::string res = textclass;
+      textclass = cls;
+      return res;
+    }
     
+    bool setXMLOutput( bool b, const std::string& id) { bool t = xmlout; docid = id; xmlout = b; return t; }
+    bool setXMLInput( bool b ) { bool t = xmlin; xmlin = b; return t; }
     
-    bool setXMLOutput(bool b, std::string id) { bool t = xmlout; docid = id; xmlout = b; return t; }
-    bool setXMLInput(bool b) { bool t = xmlin; xmlin = b; return t; }
-    
+    void outputTokens( std::ostream&, const std::vector<Token>& ) const;
+  private:
+    void tokenizeWord( const UnicodeString&, bool);    
+
+    bool detectEos( size_t ) const;
+    void detectSentenceBounds( const int offset = 0 );
+    void detectQuotedSentenceBounds( const int offset = 0 );
+    void detectQuoteBounds( const int );
     //Signal the tokeniser that a paragraph is detected
     void signalParagraph( bool b=true ) { paragraphsignal = b; };
-    
-    
-    void outputTokens( std::ostream&, const size_t, const size_t, const bool = false) const;
-    void outputTokensXML( folia::Document& , const size_t, const size_t, bool&);
-    void outputTokensXML( folia::FoliaElement * root, const size_t begin, const size_t end,  bool& in_paragraph, bool root_is_paragraph=false, bool root_is_sentence=false);
-  private:
-    void tokenizeWord( const UnicodeString&, bool);
-    
-    //Turn buffered tokens into a UnicodeString contai, also outputs types and roles in verbose mode
-    
+        
     bool resolveQuote( int, const UnicodeString& );
-    bool detectEos( UChar );
-
+    bool u_isquote( UChar );
+    std::string checkBOM( const std::string&, std::string& );
     bool readsettings( const std::string& );
     bool readrules( const std::string& );
     bool readfilters( const std::string& );
     bool readquotes( const std::string& );
     bool readeosmarkers( const std::string& );
+    bool readabbreviations( const std::string&, UnicodeString& );
     
-    //Don't use this in normal processing, use flushSentences instead
-    void clear() { tokens.clear(); quotes.clearStack(); };
+    void sortRules( std::vector<Rule *>&, std::vector<UnicodeString>& );
+    void outputTokensDoc( folia::Document&, const std::vector<Token>& ) const;
+    void outputTokensXML( folia::FoliaElement *, const std::vector<Token>& ) const;
+    void tokenizeElement( folia::FoliaElement * );
+    void tokenizeSentenceElement( folia::FoliaElement * );         
+    //return the sentence with the specified index in a Token vector;
+    std::vector<Token> getSentence( int );
 
     Quoting quotes;
     UnicodeFilter filter;
@@ -281,12 +275,10 @@ namespace Tokenizer {
     UnicodeString eosmarkers;
     std::string inputEncoding;
 
-    std::string eosmark;
+    UnicodeString eosmark;
     std::vector<Token> tokens;
-        
     std::vector<Rule *> rules;
-    std::ostream *theErrLog;
-
+    TiCC::LogStream *theErrLog;
     
     //debug flag
     int tokDebug;
@@ -308,28 +300,21 @@ namespace Tokenizer {
     
     //has a paragraph been signaled?
     bool paragraphsignal;
-    //has a sentence been signaled?
-    bool sentencesignal;
     
     //one sentence per line output
     bool sentenceperlineoutput;
     bool sentenceperlineinput;
     
 
-    bool firstoutput;
     bool lowercase;
     bool uppercase;
     bool xmlout;  
     bool xmlin;  
     bool passthru;
-    
-    int parCount;
 
     std::string settingsfilename;
-    
     std::string docid; //document ID (UTF-8), necessary for XML output 
-  private:
-    void sortRules( std::vector<Rule *>&, std::vector<UnicodeString>& );
+    std::string textclass; // class for folia text
   };
 
   template< typename T >
