@@ -1,7 +1,7 @@
 /*
-  $Id: ucto.cxx 14472 2012-03-19 10:54:28Z sloot $
+  $Id: ucto.cxx 15910 2013-04-03 13:57:51Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/ucto/trunk/src/ucto.cxx $
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK  -  Tilburg University
   CNTS -  University of Antwerp
  
@@ -31,8 +31,8 @@
 #include <string>
 #include <iostream>
 #include <fstream>
+#include "libfolia/document.h"
 #include "ucto/tokenize.h"
-#include "libfolia/folia.h"
 #include <unistd.h>
 
 using namespace std;
@@ -63,6 +63,7 @@ void usage(){
        << "\t-F              - Input file is in FoLiA XML. All untokenised sentences will be tokenised." << endl
        << "\t-X              - Output FoLiA XML, use the Document ID specified with --id=" << endl
        << "\t--id <DocID>    - use the specified Document ID to label the FoLia doc." << endl
+       << "\t--textclass <class> - use the specified class to search text in the the FoLia doc." << endl
        << "\t                  (-x and -F disable usage of most other options: -nulPQVsS)" << endl;
 }
 
@@ -81,6 +82,7 @@ int main( int argc, char *argv[] ){
   bool verbose = false;
   string eosmarker = "<utt>";
   string docid = "untitleddoc";
+  string textclass = "current";
   string normalization = "NFC";
   string inputEncoding = "UTF-8";
   string cfile = "tokconfig-en";
@@ -91,6 +93,7 @@ int main( int argc, char *argv[] ){
 
   static struct option longOpts[] = { { "passthru", 0, 0, 1 },
 				      { "id", 1, 0, 2 },
+				      { "textclass", 1, 0, 3 },
 				      { 0,0,0,0} };
 
   int opt;
@@ -119,12 +122,13 @@ int main( int argc, char *argv[] ){
 	case 'm': sentenceperlineinput = true; break;
 	case 'N': normalization = optarg; break;
 	case 'v': verbose = true; break;
-	case 'V': cout << "Ucto - Unicode Tokenizer - version " << Version() << endl << "(c) ILK 2009 - 2012, Induction of Linguistic Knowledge Research Group, Tilburg University" << endl << "Licensed under the GNU General Public License v3" << endl; 
+	case 'V': cout << "Ucto - Unicode Tokenizer - version " << Version() << endl << "(c) ILK 2009 - 2013, Induction of Linguistic Knowledge Research Group, Tilburg University" << endl << "Licensed under the GNU General Public License v3" << endl; 
 	  cout << "based on [" << folia::VersionName() << "]" << endl;
 	  return EXIT_SUCCESS;
 	case 'x': xmlout = true; docid = optarg; break;
 	case 'X': xmlout = true; break;
 	case 2: docid = optarg; break;
+	case 3: textclass = optarg; break;
 	default: usage(); return EXIT_SUCCESS;
 	}
     }
@@ -211,6 +215,7 @@ int main( int argc, char *argv[] ){
     tokenizer.setNormalization( normalization );
     tokenizer.setInputEncoding( inputEncoding );
     tokenizer.setFiltering(dofiltering);
+    tokenizer.setTextClass(textclass);
     tokenizer.setXMLOutput(xmlout, docid);
     tokenizer.setXMLInput(xmlin);
 
